@@ -10,9 +10,9 @@ from ensurepip import rewheel
 __all__ = ["version", "bootstrap"]
 
 
-_SETUPTOOLS_VERSION = "12.0.5"
+_SETUPTOOLS_VERSION = "18.2"
 
-_PIP_VERSION = "7.0.3"
+_PIP_VERSION = "7.1.0"
 
 # pip currently requires ssl support, so we try to provide a nicer
 # error message when that is missing (http://bugs.python.org/issue19744)
@@ -160,7 +160,7 @@ def _uninstall_helper(*, verbosity=0):
     _disable_pip_configuration_settings()
 
     # Construct the arguments to be passed to the pip command
-    args = ["uninstall", "-y"]
+    args = ["uninstall", "-y", "--disable-pip-version-check"]
     if verbosity:
         args += ["-" + "v" * verbosity]
 
